.. :changelog:

History
-------

0.3.1 (2014-08-25)
++++++++++++++++++

* Add staticfiles application;
* Add djangocms_admin_style if cms is enabled;

0.3.0 (2014-08-14)
++++++++++++++++++

* Add support for django nose test runner;
* Add default CMS template;

0.2.0 (2014-08-12)
++++++++++++++++++

* Add option to customize sample project settings;
* Add option to exclude djanigo CMS from test project configurations;
* Add support for Django 1.7;

0.1.0 (2014-08-09)
++++++++++++++++++

* First public release.
